persistent_surmise
------------------

Required: Surmise_

Note that currently the github fork https://github.com/mosesyhc/surmise should be used::

    python -m pip install --upgrade git+https://github.com/mosesyhc/surmise.git

The :doc:`Borehole Calibration tutorial<../tutorials/calib_cancel_tutorial>` uses this generator as an example of the capability to cancel pending simulations.

.. automodule:: persistent_surmise_calib
  :members:
  :no-undoc-members:

.. _Surmise: https://surmise.readthedocs.io/en/latest/index.html
